import setuptools

setuptools.setup(
     name='tasslab',
     version='0.0.4',
     author="Nebo",
     author_email="bozanic@stanford.edu",
     description="phase reset package",
     url="https://github.com/nebojshaki/tasslab",
     packages=setuptools.find_packages(),
     classifiers=[
         "Programming Language :: Python :: 3",
         "License :: OSI Approved :: MIT License",
         "Operating System :: Microsoft :: Windows :: Windows 10",
     ],
 )


# A module containing several functions to compute the phase reset index
# Nebojsa Bozanic <bozanic@stanford.edu> Copyright 2020
# Distributed under the BSD License

import phasereset

def test():

 return 0